# I-ReaxFF: stand for Intelligent-Reactive Force Field

- I-ReaxFF is a differentiable ReaxFF framework based on TensorFlow, with which we can get the first and high order derivatives of energies, and also can optimize ReaxFF parameters with integrated optimizers in TensorFlow.
---

ffield.json: the parameter file from machine learning
reaxff_nn.lib  the parameter file converted from ffield.json for usage with GULP

## Requirement
 the following package need to be installed
1. TensorFlow, pip install tensorflow --user or conda install tensorflow
2. Numpy,pip install numpy --user
3. matplotlib, pip install matplotlib --user

Install this package just run commond in shell "python setup install --user"

## Example
An example usage can be found in director I-ReaxFF/example

## Refference
Intelligent-ReaxFF: Evaluating the reactive force field parameters with machine
learning, Computational Materials Science 172 (2020) 109393 
